# modpack-converter
Convert's one modpack format to another.

Maybe I need to think of a better name...

# How to Install

## From PyPI
```
pip install mc-converter
```
## From `.whl` file
Go to Release page, download latest `.whl` file \
 And install it via the following comand:
 ```
 pip install mc_converter_{version}.whl
 ```
 